@@ -1,14 +1,14 @@
 """Predictor class to train and test models per use-case."""
-
 import logging
 from os import path
 from typing import Optional
 
+import numpy as np
 import yaml
 
-from cyclops.models.catalog import MODELS, PT_MODELS, STATIC_MODELS, _Model
+from cyclops.models.catalog import _model_catalog, _static_model_keys, create_model
 from cyclops.models.constants import (
-    CONFIG_FILE,
+    CONFIG_ROOT,
     DATA_DIR,
     DATA_TYPES,
     DATASETS,
@@ -16,24 +16,20 @@ from cyclops.models.constants import (
     TASKS,
     USE_CASES,
 )
-from cyclops.models.data import VectorizedLoader
-from cyclops.models.util import get_device, metrics_binary
-from cyclops.models.wrapper import PTModel, SKModel
-from cyclops.utils.file import join, process_dir_save_path
+from cyclops.models.data import PTDataset, VectorizedLoader
+from cyclops.models.utils import metrics_binary
+from cyclops.models.wrappers import PTModel, WrappedModel
+from cyclops.utils.file import join
 from cyclops.utils.log import setup_logging
 
 LOGGER = logging.getLogger(__name__)
 setup_logging(print_level="INFO", logger=LOGGER)
 
-# mypy: ignore-errors
-# pylint: disable=too-many-instance-attributes
-# pylint: disable=too-many-arguments, invalid-name
-
 
 class Predictor:
     """Predictor class."""
 
-    def __init__(
+    def __init__(  # pylint: disable=too-many-arguments,
         self,
         model_name: str,
         dataset_name: str,
@@ -63,11 +59,13 @@ class Predictor:
             Path to the directory to save checkpoints.
 
         """
-        self.model_name = model_name.lower()
+        self.model_name = model_name
         self.dataset_name = dataset_name.lower()
         self.use_case = use_case.lower()
         self.data_type = data_type.lower()
-        self.config_file = config_file if config_file else CONFIG_FILE
+        self.config_file = (
+            config_file if config_file else join(CONFIG_ROOT, self.model_name + ".yaml")
+        )
         self.data_dir = (
             data_dir
             if data_dir
@@ -80,15 +78,11 @@ class Predictor:
             )
         )
         self.save_dir = save_dir if save_dir else SAVE_DIR
-        self.device = get_device()
 
         self._validate()
 
         self.dataset = VectorizedLoader(
-            self.dataset_name,
-            self.use_case,
-            self.data_type,
-            self.data_dir,
+            self.dataset_name, self.use_case, self.data_type, self.data_dir
         )
 
         (
@@ -101,27 +95,17 @@ class Predictor:
         ) = self.dataset.data
 
         with open(self.config_file, "r", encoding="utf8") as file:
-            params = yaml.load(file, Loader=yaml.FullLoader)[self.model_name]
+            params = yaml.load(file, Loader=yaml.FullLoader)
 
-        save_path = join(
-            self.save_dir, self.dataset_name, self.data_type, self.model_name
-        )
-        process_dir_save_path(save_path)
+        # save_path = join(SAVE_DIR, self.model_name, self.dataset_name, self.data_type)
+        # process_dir_save_path(save_path)
+        model_params = params.get("model_params", None) or params
 
-        if self.model_name in PT_MODELS:
-            params["model_params"]["input_dim"] = self.dataset.n_features
-            params["model_params"]["device"] = self.device
-            if params["train_params"]["reweight"] == "total":
-                params["train_params"]["reweight"] = (self.y_train == 0).sum() / (
-                    self.y_train == 1
-                ).sum()
-            self.model = PTModel(self.model_name, save_path, **params)
-        else:
-            self.model = SKModel(self.model_name, save_path, **params)
+        self.model = create_model(self.model_name, **model_params)
 
     def _validate(self) -> None:
         """Validate the input arguments."""
-        assert self.model_name in MODELS, "[!] Invalid model name"
+        assert self.model_name in _model_catalog, "[!] Invalid model name"
         assert self.dataset_name in DATASETS, "[!] Invalid dataset name"
         assert (
             self.use_case in USE_CASES.keys()  # pylint: disable=C0201
@@ -130,65 +114,63 @@ class Predictor:
             self.dataset_name in USE_CASES[self.use_case]
         ), "[!] Unsupported use case for this dataset"
         assert self.data_type in DATA_TYPES, "[!] Invalid data type"
-        if self.model_name in STATIC_MODELS:
+        if self.model_name in _static_model_keys:
             assert (
                 self.data_type == "tabular"
             ), "[!] The data type and model are not compatiable"
         assert path.exists(self.data_dir), "[!] Data path does not exist."
         assert path.exists(self.config_file), "[!] Config path does not exist."
 
-    def fit(self) -> _Model:
+    def fit(self):
         """Train the model through appropriate wrapper.
 
         Returns
         -------
-        _Model
-            The trained model.
+        self
 
         """
-        return self.model.fit(self.X_train, self.y_train, self.X_val, self.y_val)
+        self.model = self.model.fit(self.X_train, self.y_train)
+        return self
 
-    def predict(self, trained_model: _Model) -> tuple:
+    def predict(self) -> np.ndarray:
         """Make prediction by a trained model.
 
-        Parameters
-        ----------
-        trained_model : _Model
-            The pretrained model.
-
         Returns
         -------
-        tuple
-            Tuple of test labels, predicted values, and predicted labels.
+        np.ndarray
+            The model predictions.
 
         """
-        return self.model.predict(trained_model, self.X_test, self.y_test)
+        if isinstance(self.model, PTModel):
+            test_dataset = PTDataset(self.X_test, self.y_test)
+            return self.model.predict(test_dataset)
+        return self.model.predict(self.X_test)
 
-    def load_model(self, model_path: Optional[str] = None) -> _Model:
+    def load_model(self, filepath: str, **kwargs) -> WrappedModel:
         """Load model from a file.
 
         Parameters
         ----------
-        model_path : Optional[str], optional
-            Path to the saved model/checkpoint, by default None.
+        filepath : str
+            Path to the model file.
+        **kwargs
+            Additional arguments.
 
         Returns
         -------
-        _Model
-            Model object.
+        WrappedModel
+            The loaded model object.
 
         """
-        return self.model.load_model(model_path)
+        return self.model.load_model(filepath, **kwargs)
 
-    def evaluate(self, trained_model: _Model, verbose: bool) -> dict:
+    def evaluate(self, verbose: bool) -> dict:
         """Evaluate a trained model based on various metrics.
 
         Parameters
         ----------
-        trained_model : _Model
-            The pretrained model.
         verbose : bool
-            Whether to print the evaluation results.
+            Print the evaluation results.
 
         Returns
         -------
@@ -197,18 +179,16 @@ class Predictor:
 
         """
         if self.use_case in TASKS["binary_classification"]:
-            return self.evaluate_binary(trained_model, verbose)
+            return self.evaluate_binary(verbose)
         return {}
 
-    def evaluate_binary(self, trained_model: _Model, verbose: bool) -> dict:
+    def evaluate_binary(self, verbose: bool) -> dict:
         """Evaluate a model on binary calssification metrics.
 
         Parameters
         ----------
-        trained_model : _Model
-            The pretrained model.
         verbose : bool
-            Whether to print the evaluation results.
+            Print the evaluation results.
 
         Returns
         -------
@@ -216,9 +196,9 @@ class Predictor:
             Dictionary of evaluation metrics and values.
 
         """
-        y_test_labels, y_pred_values, y_pred_labels = self.predict(trained_model)
-        y_pred_values = y_pred_values[y_test_labels != -1]
-        y_pred_labels = y_pred_labels[y_test_labels != -1]
-        y_test_labels = y_test_labels[y_test_labels != -1]
+        preds = self.predict()
+        preds = preds[self.y_test != -1]
+        y_pred_labels = preds > 0.5  # HACK: hard-coded threshold
+        y_test_labels = self.y_test[self.y_test != -1]
 
-        return metrics_binary(y_test_labels, y_pred_values, y_pred_labels, verbose)
+        return metrics_binary(y_test_labels, preds, y_pred_labels, verbose)
