@@ -2,8 +2,9 @@
 
 import logging
 from dataclasses import dataclass, field
-from typing import Callable, Dict, Generator, Optional, Union
+from typing import Callable, Dict, Literal, Optional, Union
 
+import dask.dataframe as dd
 import pandas as pd
 
 from cyclops.query.orm import Database
@@ -26,7 +27,7 @@ class QueryInterface:
         Database object to create ORM, and query data.
     query: cyclops.query.util.TableTypes
         The query.
-    data: pandas.DataFrame
+    data: pandas.DataFrame or dask.DataFrame
         Data returned from executing the query, as Pandas DataFrame.
     _run_args: dict
         Private dictionary attribute to keep track of arguments
@@ -36,41 +37,59 @@ class QueryInterface:
 
     database: Database
     query: TableTypes
-    data: Optional[pd.DataFrame] = None
+    data: Optional[Union[pd.DataFrame, dd.DataFrame]] = None
     _run_args: Dict = field(default_factory=dict)
 
     def run(
         self,
         limit: Optional[int] = None,
-    ) -> pd.DataFrame:
+        backend: Literal["pandas", "dask"] = "pandas",
+        index_col: Optional[str] = None,
+        n_partitions: Optional[int] = None,
+    ) -> Union[pd.DataFrame, dd.DataFrame]:
         """Run the query, and fetch data.
 
         Parameters
         ----------
-        limit: int, optional
+        limit
             No. of rows to limit the query return.
+        backend
+            Backend computing framework to use, Pandas or Dask.
+        index_col
+            Column which becomes the index, and defines the partitioning.
+            Should be a indexed column in the SQL server, and any orderable type.
+        n_partitions
+            Number of partitions. Check dask documentation for additional details.
 
         Returns
         -------
-        pandas.DataFrame
+        pandas.DataFrame or dask.DataFrame
             Query result dataframe.
 
         """
-        # Only re-run when new run arguments are given
+        # Only re-run when new run arguments are given.
         if self.data is None or not self._run_args == locals():
             self._run_args = locals()
-            self.data = self.database.run_query(self.query, limit=limit)
+            self.data = self.database.run_query(
+                self.query,
+                limit=limit,
+                backend=backend,
+                index_col=index_col,
+                n_partitions=n_partitions,
+            )
 
         return self.data
 
-    def save(self, path: str, file_format: str = "parquet") -> str:
+    def save(
+        self, path: str, file_format: Literal["parquet", "csv"] = "parquet"
+    ) -> str:
         """Save the query.
 
         Parameters
         ----------
-        save_path: str
+        save_path
             Path where the file will be saved.
-        file_format: str
+        file_format
             File format of the file to save.
 
         Returns
@@ -79,12 +98,12 @@ class QueryInterface:
             Processed save path for upstream use.
 
         """
-        # If the query was already run
+        # If the query was already run.
         if self.data is not None:
             path = save_dataframe(self.data, path, file_format=file_format)
             return path
 
-        # Save without running
+        # Save without running.
         if file_format == "csv":
             path = self.database.save_query_to_csv(self.query, path)
         elif file_format == "parquet":
@@ -102,70 +121,12 @@ class QueryInterface:
         """
         self.data = None
 
-    def run_in_grouped_batches(
-        self, id_col: str, batch_size: int
-    ) -> Generator[pd.DataFrame, None, None]:
-        """Run the query in batches with complete sets of sample IDs.
-
-        Queries are sorted and grouped such that the rows for a given sample ID are kept
-        together in a single batch.
-
-        Parameters
-        ----------
-        id_col: str
-            Name of the sample ID column by which to batch.
-        batch_size: int
-            Approximate batch size before rearranging based on sample IDs.
-
-        Yields
-        ------
-        pandas.DataFrame
-            A query batch with complete sets of sample IDs.
-
-        """
-        generator = self.database.run_id_batched_query(self.query, id_col, batch_size)
-        while True:
-            try:
-                yield next(generator)
-            except StopIteration:
-                return
-
-    def save_in_grouped_batches(
-        self,
-        dir_path: str,
-        id_col: str,
-        batch_size: int,
-        file_format: str = "parquet",
-    ) -> None:
-        """Save a query in different batches, keeping same sample IDs together.
-
-        Queries are sorted and grouped such that the rows for a given sample ID are kept
-        together in a single batch.
-
-        Parameters
-        ----------
-        query: cyclops.query.util.TableTypes
-            Query to run.
-        dir_path: str
-            Path to directory in which to save the batches.
-        batch_size: int
-            Approximate batch size before rearranging based on sample IDs.
-        id_col: str
-            Name of the sample ID column by which to batch.
-        file_format: str
-            File format of the DataFrame to save.
-
-        """
-        self.database.save_id_batched_query(
-            self.query, dir_path, id_col, batch_size, file_format=file_format
-        )
-
 
 @dataclass
 class QueryInterfaceProcessed:
     """An interface dataclass to wrap queries, and run them with post-processing.
 
-    An similar dataclass to QueryInterface, where custom post-processing
+    A similar dataclass to QueryInterface, where custom post-processing
     functions on the pandas dataframe returned from the query can be run. However,
     this prevents the query from being further used, and hence is declared as
     private attribute.
@@ -178,13 +139,10 @@ class QueryInterfaceProcessed:
         The query.
     process_fn: Callable
         Process function to apply on the pandas dataframe returned from the query.
-
-    Attributes
-    ----------
     _run_args: dict
         Private dictionary attribute to keep track of arguments
         passed to run() method.
-    data: pandas.DataFrame
+    data: pandas.DataFrame or dask.DataFrame
         Data returned from executing the query, as Pandas DataFrame.
 
     """
@@ -192,29 +150,46 @@ class QueryInterfaceProcessed:
     database: Database
     _query: TableTypes
     process_fn: Callable
-    data: Union[pd.DataFrame, None] = None
+    data: Optional[Union[pd.DataFrame, dd.DataFrame, None]] = None
     _run_args: Dict = field(default_factory=dict)
 
     def run(
         self,
         limit: Optional[int] = None,
-    ) -> pd.DataFrame:
+        backend: Literal["pandas", "dask"] = "pandas",
+        index_col: Optional[str] = None,
+        n_partitions: Optional[int] = None,
+    ) -> Union[pd.DataFrame, dd.DataFrame]:
         """Run the query, and fetch data.
 
         Parameters
         ----------
-        limit: int, optional
+        limit
             No. of rows to limit the query return.
+        backend
+            Backend computing framework to use, Pandas or Dask.
+        index_col
+            Column which becomes the index, and defines the partitioning.
+            Should be a indexed column in the SQL server, and any orderable type.
+        n_partitions
+            Number of partitions. Check dask documentation for additional details.
 
         Returns
         -------
-        pandas.DataFrame
+        pandas.DataFrame or dask.DataFrame
             Query result dataframe.
 
         """
+        # Only re-run when new run arguments are given.
         if self.data is None or not self._run_args == locals():
             self._run_args = locals()
-            self.data = self.database.run_query(self._query, limit=limit)
+            self.data = self.database.run_query(
+                self._query,
+                limit=limit,
+                backend=backend,
+                index_col=index_col,
+                n_partitions=n_partitions,
+            )
 
             LOGGER.info(
                 "Applying post-processing fn %s to query output",
@@ -224,14 +199,16 @@ class QueryInterfaceProcessed:
 
         return self.data
 
-    def save(self, path: str, file_format: str = "parquet") -> str:
+    def save(
+        self, path: str, file_format: Literal["parquet", "csv"] = "parquet"
+    ) -> str:
         """Save the processed query.
 
         Parameters
         ----------
-        save_path: str
+        save_path
             Path where the file will be saved.
-        file_format: str
+        file_format
             File format of the file to save.
 
         Returns
@@ -243,8 +220,8 @@ class QueryInterfaceProcessed:
         # The query must be run in order to be processed.
         if self.data is None:
             self.run()
-
         path = save_dataframe(self.data, path, file_format=file_format)
+
         return path
 
     def clear_data(self) -> None:
